# 引力波数据探索：编程与分析实战训练营
# Gravitational Wave Data Exploration: A Practical Training in Programming and Analysis

> Under construction...

Welcome to the GitHub repository for the Gravitational Wave Data Exploration Bootcamp Series! 
This course is meticulously designed to provide a solid foundation in programming, operational knowledge, and data-driven modeling skills centered around gravitational wave data analysis and research.

<img src="logo-taiji.jpg" style="width:20%;height:auto;">

## Training Objectives
- Equip participants with robust programming and operational skills, and foundational training in data-driven modeling, focusing on gravitational wave data analysis and related research areas.
- **Note: The course is conducted entirely in Mandarin Chinese to cater to a wide range of Chinese-speaking students and researchers.**
- Discuss the common research methodologies combining gravitational wave data processing with AI technologies, with hands-on examples and projects for practical understanding and mastery.
- Analyze cutting-edge deep learning models and apply them to real-world gravitational wave data analysis problems through specific case studies.

## Target Audience
- Undergraduate and graduate students interested in data analysis and algorithm development, especially those focusing on gravitational wave data processing and related research.
- The course also welcomes undergraduates with a basic programming background, looking to enhance their data analysis skills or with an interest in gravitational wave data processing.
- Future professionals aspiring to work in space-based gravitational wave detection projects and related research fields.

## Course Design Philosophy
- Drawing from past teaching experiences and identified knowledge gaps in student research projects, the course introduces relevant concepts and common methods to ensure comprehensive understanding and application in research.
- The course is scheduled weekly or bi-weekly, each session lasting about 3 hours, combining online and offline methods (腾讯会议) to ensure interactivity and practicality.
- The curriculum is expected to be offered once per semester or annually, with continual updates and enrichment based on student feedback and research demands.

## Course Outline / Schedule
- **Part Zero**: Motivational Introduction: [2023/11/08](2023/intro/readme.md)
- **Part One**: Programming Development Environment and Workflow: [2023/11/12](2023/workflow/readme.md)
  - Linux Commands and Shell Scripting
  - Git Version Control (GitHub / GitLab)
  - SSH Remote Server Access (Shell / VSCode)
  - Containerization with Docker
  - Hands-On: Setting up Python / Jupyter Development Environment
  - Hands-On: Compiling LALsuite / LISAcode Source Code

- **Part Two**: Python-Based Data Analysis Fundamentals
  - Introduction to Python Programming
  - Algorithms with Numpy / Pandas / Scipy
  - Hands-On: Exploratory Data Analysis of GW Event Catalog / Glitch Data
  - Hands-On: Matched Filtering for GW150914 Data
  - Data Visualization in Python: Theory and Practice
  - Hands-On: Reproducing Figures from GWTC Papers

- **Part Three**: Basics of Machine Learning
  - Overview of Artificial Intelligence
  - Definitions, Objectives, and Types of Machine Learning
  - Machine Learning Project Development and Preparation
  - Hands-On: Clustering Analysis of LIGO's Glitch Data

- **Part Four**: Introduction to Deep Learning
  - Overview of Deep Learning Technologies
  - Fundamentals of Artificial Neural Networks (ANN)
  - Convolutional Neural Networks (CNN)
  - Hands-On: Identifying Gravitational Waves from Binary Black Hole Systems using CNN
  - Frontiers of Gravitational Wave Data Analysis and AI

## Getting Started
To participate in this course:

1. Clone the repository:
   ```bash
   git clone https://github.com/iphysresearch/GWData-Bootcamp.git
   ```

(Under construction)

## Staff
This class is co-taught by [He Wang](https://iphysresearch.github.io/blog/) and several esteemed colleagues, including guest lecturers and industry experts, whose names will be announced as they join.

## Questions
For any inquiries regarding the course, please email us at [📧 taiji@ucas.ac.cn](mailto:taiji@ucas.ac.cn).

We look forward to your participation and contribution to this exciting field of study!

## Contributing

We welcome contributions to enhance course materials. Please fork the repository, make your changes, and submit a pull request.

## Collaborating Institutions
- [University of Chinese Academy of Sciences](http://english.ucas.ac.cn/) (UCAS)

  <img src="logo-ucas.png" style="width:30%;height:auto;">

- [International Centre for Theoretical Physics Asia-Pacific](https://ictp-ap.org/) (ICTP-AP)

  <img src="logo-ictp-ap.png" style="width:30%;height:auto;"> 
  
- [Taiji Laboratory for Gravitational Wave Universe](https://ictp-ap.org/page/taiji-laboratory)

  <img src="logo-taiji-lab.png" style="width:20%;height:auto;">

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

## Acknowledgments

- Contributions from the Gravitational Wave Open Science Center ([gwosc.org](https://gwosc.org/)).
- Educational resources and datasets from renowned institutions and projects in the field.

